flash: Rename write_flash to flash_write

Change-Id: I4b41aac597299c93369d8998b03a7d3e2a128742
Signed-off-by: Andrew Jeffery <andrew@aj.id.au>
diff --git a/flash.c b/flash.c
index 0f0b6b5..6fb9c2c 100644
--- a/flash.c
+++ b/flash.c
@@ -259,7 +259,7 @@
 }
 
 /*
  * write_flash() - Write the flash from a provided buffer
  * @context:	The mbox context pointer
  * @offset:	The flash offset to write to (bytes)
  * @buf:	The buffer to write from (must be of atleast size)
@@ -267,7 +267,7 @@
  *
  * Return:	0 on success otherwise negative error code
  */
-int write_flash(struct mbox_context *context, uint32_t offset, void *buf,
+int flash_write(struct mbox_context *context, uint32_t offset, void *buf,
 		uint32_t count)
 {
 	uint32_t buf_offset = 0;
@@ -259,7 +259,7 @@
 
 /*
- * write_flash() - Write the flash from a provided buffer
+ * flash_write() - Write the flash from a provided buffer
  * @context:	The mbox context pointer
  * @offset:	The flash offset to write to (bytes)